<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:container="urn:oasis:names:tc:opendocument:xmlns:container"
    xmlns:html="http://www.w3.org/1999/xhtml"
    xmlns:ncx="http://www.daisy.org/z3986/2005/ncx/"
    xmlns:opf="http://www.idpf.org/2007/opf"
    exclude-result-prefixes="xs"
    version="2.0">
    <xsl:output indent="yes" method="xml"/>
    <xsl:param name="outpath" select="'../temp/transformed/'"/>
    
    <xsl:template match="/">
        <xsl:variable name="rootDir" select="substring-before(base-uri(),'META-INF')"/>
        <xsl:message>rootDir = <xsl:value-of select="$rootDir"/></xsl:message>
        <xsl:variable name="opfPath" select="concat($rootDir,container:container/container:rootfiles/container:rootfile[@media-type = 'application/oebps-package+xml']/@full-path)"/>
        <xsl:variable name="opfDir" select="concat(string-join(tokenize($opfPath,'/')[position() &lt; (last())],'/'),'/')"/>
        <xsl:message>opfPath = <xsl:value-of select="$opfPath"/></xsl:message>
        <xsl:message>opfDir = <xsl:value-of select="$opfDir"/></xsl:message>
        <xsl:variable name="ncxPath" select="concat($opfDir,document($opfPath,/)//opf:item[@media-type='application/x-dtbncx+xml']/@href)"/>        
        <xsl:message>ncxPath = <xsl:value-of select="$ncxPath"/></xsl:message>
        
        <xsl:for-each select="document($opfPath,/)//opf:spine/opf:itemref">
                <xsl:apply-templates select="document($opfPath,/)//opf:manifest/opf:item[@id = current()/@idref]"/>
        </xsl:for-each>
    </xsl:template>
    
    <xsl:template match="opf:item">
        <xsl:message>Current Item: <xsl:value-of select="@id"/>, file <xsl:value-of select="@href"/></xsl:message>
        <xsl:message>Processing HTML file</xsl:message>
        <xsl:result-document href="{$outpath}OEBPS/{@href}" method="xhtml" exclude-result-prefixes="#all" version="1.1">
            <xsl:apply-templates select="document(@href,/)" mode="html"/>
        </xsl:result-document>
    </xsl:template>
 
    <xsl:template match="html:span[@class='numpage']">
        <xsl:copy>
            <xsl:attribute name="id" select="generate-id()"/>
            <xsl:apply-templates select="@*|node()"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="/" mode="html">
        <xsl:apply-templates select="*"/>
    </xsl:template>
    
    <xsl:template match="html:*">
        <xsl:copy>
            <xsl:apply-templates select="node()|@*" />
        </xsl:copy>
    </xsl:template>

    <xsl:template match="processing-instruction()">
        <xsl:copy/>
    </xsl:template>
    
    <xsl:template match="@*">
        <xsl:copy/>
    </xsl:template>
    
    <xsl:template match="text()">
         <xsl:copy/>
    </xsl:template>
    
</xsl:stylesheet>